@@ -6,10 +6,10 @@ environ['PYGAME_HIDE_SUPPORT_PROMPT'] = '1'
 
 import pygame
 import pytmx
-from objects import Block
-from objects import PhysObject, Player, YellowPower
-from GlobalVars import GlobalVars
-from Level import Level
+from bluebeam.objects import Block
+from bluebeam.objects import PhysObject, Player, YellowPower
+from bluebeam.GlobalVars import GlobalVars
+from bluebeam.Level import Level
 from pytmx.util_pygame import load_pygame
 from pygame import mixer
 import math
