@@ -7,9 +7,9 @@ environ['PYGAME_HIDE_SUPPORT_PROMPT'] = '1'
 import pygame
 import pytmx
 
-from GlobalVars import GlobalVars
+from bluebeam.GlobalVars import GlobalVars
 #import GlobalVars
-from Level import Level
+from bluebeam.Level import Level
 from pytmx.util_pygame import load_pygame
 from pygame import mixer
 import time
