@@ -1,6 +1,6 @@
 import math
 
-from objects import PhysObject, PlayerBullet, YellowPower, BossSpawnTrigger
+from bluebeam.objects import PhysObject, PlayerBullet, YellowPower, BossSpawnTrigger
 import pygame
 import os
 
