@@ -1,4 +1,4 @@
-from objects import EnemyBullet
+from bluebeam.objects import EnemyBullet
 import pygame
 
 
